[Libreoffice-commits] .: sw/inc

Christoph Herzog cherzog at kemper.freedesktop.org
Sun Feb 6 17:08:59 PST 2011


 sw/inc/fmtftn.hxx   |    2 -
 sw/inc/fmthdft.hxx  |    4 +-
 sw/inc/fmtinfmt.hxx |   18 ++++-----
 sw/inc/fmtline.hxx  |    6 +--
 sw/inc/fmtornt.hxx  |   13 +++---
 sw/inc/fmtpdsc.hxx  |   20 +++++-----
 sw/inc/fmtrfmrk.hxx |    8 ++--
 sw/inc/fmtruby.hxx  |   14 +++----
 sw/inc/fmtsrnd.hxx  |    6 +--
 sw/inc/fmturl.hxx   |   14 +++----
 sw/inc/format.hxx   |  104 +++++++++++++++++++++++++---------------------------
 11 files changed, 101 insertions(+), 108 deletions(-)

New commits:
commit 5943f0bd5fff451bd9210f16bb173029ba946854
Author: Christoph Herzog <rhogez at googlemail.com>
Date:   Mon Feb 7 02:08:11 2011 +0100

    Translation of German comments.

diff --git a/sw/inc/fmtftn.hxx b/sw/inc/fmtftn.hxx
index 1e6d6cb..5211164 100644
--- a/sw/inc/fmtftn.hxx
+++ b/sw/inc/fmtftn.hxx
@@ -73,7 +73,7 @@ public:
 
     void GetFtnText( String& rStr ) const;
 
-    // returnt den anzuzeigenden String der Fuss-/Endnote
+    // Returns string to be displayed of footnote / endnote.
     String GetViewNumStr( const SwDoc& rDoc, BOOL bInclStrs = FALSE ) const;
 };
 
diff --git a/sw/inc/fmthdft.hxx b/sw/inc/fmthdft.hxx
index 548acea..9aa6d08 100644
--- a/sw/inc/fmthdft.hxx
+++ b/sw/inc/fmthdft.hxx
@@ -42,7 +42,7 @@ class IntlWrapper;
 
 class SW_DLLPUBLIC SwFmtHeader: public SfxPoolItem, public SwClient
 {
-    BOOL bActive;		//Nur zur Steuerung (Erzeugung des Inhaltes)
+    BOOL bActive;		// Only for controlling (creation of content).
 
 public:
     SwFmtHeader( BOOL bOn = FALSE );
@@ -74,7 +74,7 @@ public:
 
 class SW_DLLPUBLIC SwFmtFooter: public SfxPoolItem, public SwClient
 {
-    BOOL bActive;		//Nur zur Steuerung (Erzeugung des Inhaltes)
+    BOOL bActive;		// Only for controlling (creation of content).
 
 public:
     SwFmtFooter( BOOL bOn = FALSE );
diff --git a/sw/inc/fmtinfmt.hxx b/sw/inc/fmtinfmt.hxx
index 78857ee..d0f005b 100644
--- a/sw/inc/fmtinfmt.hxx
+++ b/sw/inc/fmtinfmt.hxx
@@ -37,30 +37,30 @@ class SvxMacroTableDtor;
 class SwTxtINetFmt;
 class IntlWrapper;
 
-// ATT_INETFMT *********************************************
+// ATT_INETFMT
 
 class SW_DLLPUBLIC SwFmtINetFmt: public SfxPoolItem
 {
     friend class SwTxtINetFmt;
 
-    String aURL;					// URL
-    String aTargetFrame;			// in diesen Frame soll die URL
+    String aURL;					// URL.
+    String aTargetFrame;			// Target frame for URL.
     String aINetFmt;
     String aVisitedFmt;
-    String aName;					// name of the link
+    String aName;					// Name of the link.
     SvxMacroTableDtor* pMacroTbl;
-    SwTxtINetFmt* pTxtAttr;			// my TextAttribute
+    SwTxtINetFmt* pTxtAttr;			// My TextAttribute.
     USHORT nINetId;
     USHORT nVisitedId;
 public:
     SwFmtINetFmt( const String& rURL, const String& rTarget );
     SwFmtINetFmt( const SwFmtINetFmt& rAttr );
-    SwFmtINetFmt();                     // for TypeInfo
+    SwFmtINetFmt();                     // For TypeInfo.
     virtual ~SwFmtINetFmt();
 
     TYPEINFO();
 
-    // "pure virtual methods" of SfxPoolItem
+    // "Pure virtual methods" of SfxPoolItem.
     virtual int             operator==( const SfxPoolItem& ) const;
     virtual SfxPoolItem*	Clone( SfxItemPool* pPool = 0 ) const;
     virtual SfxItemPresentation GetPresentation( SfxItemPresentation ePres,
@@ -97,11 +97,11 @@ public:
     USHORT GetVisitedFmtId() const			{ return nVisitedId; }
     void SetVisitedFmtId( USHORT nNew )		{ nVisitedId = nNew; }
 
-    // set a new MacroTable or clear the current one
+    // Set a new MacroTable or clear the current one.
     void SetMacroTbl( const SvxMacroTableDtor* pTbl = 0 );
     const SvxMacroTableDtor* GetMacroTbl() const	{ return pMacroTbl; }
 
-    // Macro getter and setter
+    // Macro getter and setter.
     void SetMacro( USHORT nEvent, const SvxMacro& rMacro );
     const SvxMacro* GetMacro( USHORT nEvent ) const;
 };
diff --git a/sw/inc/fmtline.hxx b/sw/inc/fmtline.hxx
index 7c50523..b850522 100644
--- a/sw/inc/fmtline.hxx
+++ b/sw/inc/fmtline.hxx
@@ -38,8 +38,8 @@ class IntlWrapper;
 
 class SW_DLLPUBLIC SwFmtLineNumber: public SfxPoolItem
 {
-    ULONG nStartValue	:24; //Startwert fuer den Absatz, 0 == kein Startwert
-    ULONG bCountLines	:1;	 //Zeilen des Absatzes sollen mitgezaehlt werden.
+    ULONG nStartValue	:24; // Starting value for the paragraph. 0 == no starting value.
+    ULONG bCountLines	:1;	 // Also count lines of paragraph.
 
 public:
     SwFmtLineNumber();
@@ -47,7 +47,7 @@ public:
 
     TYPEINFO();
 
-    // "pure virtual methods" of SfxPoolItem
+    // "Pure virtual methods" of SfxPoolItem.
     virtual int             operator==( const SfxPoolItem& ) const;
     virtual SfxPoolItem*	Clone( SfxItemPool* pPool = 0 ) const;
     virtual SfxItemPresentation GetPresentation( SfxItemPresentation ePres,
diff --git a/sw/inc/fmtornt.hxx b/sw/inc/fmtornt.hxx
index 7fe3e5d..8e2ef6a 100644
--- a/sw/inc/fmtornt.hxx
+++ b/sw/inc/fmtornt.hxx
@@ -44,7 +44,7 @@ class IntlWrapper;
 
 class SW_DLLPUBLIC SwFmtVertOrient: public SfxPoolItem
 {
-    SwTwips         nYPos;  //Enthaelt _immer_ die aktuelle RelPos.
+    SwTwips         nYPos;  // Contains *always* the current RelPos.
     sal_Int16       eOrient;
     sal_Int16       eRelation;
 public:
@@ -53,7 +53,7 @@ public:
                      sal_Int16 eRel = com::sun::star::text::RelOrientation::PRINT_AREA );
     inline SwFmtVertOrient &operator=( const SwFmtVertOrient &rCpy );
 
-    // "pure virtual methods" of SfxPoolItem
+    // "Pure virtual methods" of SfxPoolItem.
     virtual int             operator==( const SfxPoolItem& ) const;
     virtual SfxPoolItem*	Clone( SfxItemPool* pPool = 0 ) const;
     virtual SfxItemPresentation GetPresentation( SfxItemPresentation ePres,
@@ -73,25 +73,24 @@ public:
     void    SetPos( SwTwips nNew ) { nYPos = nNew; }
 };
 
-//  SwFmtHoriOrient, wie und woran orientiert --
-//	sich der FlyFrm in der Hoizontalen ----------
+//	SwFmtHoriOrient; how and towards what does the FlyFrm orient itself horizontally?
 
 #define IVER_HORIORIENT_TOGGLE ((USHORT)0x0001)
 #define IVER_HORIORIENT_REL ((USHORT)0x0002)
 
 class SW_DLLPUBLIC SwFmtHoriOrient: public SfxPoolItem
 {
-    SwTwips         nXPos;  //Enthaelt _immer_ die aktuelle RelPos.
+    SwTwips         nXPos;  // Contains *always* the current RelPos.
     sal_Int16       eOrient;
     sal_Int16       eRelation;
-    BOOL            bPosToggle : 1; // auf geraden Seiten Position spiegeln
+    BOOL            bPosToggle : 1; // Flip position on even pages.
 public:
     TYPEINFO();
     SwFmtHoriOrient( SwTwips nX = 0, sal_Int16 eHori = com::sun::star::text::HoriOrientation::NONE,
         sal_Int16 eRel = com::sun::star::text::RelOrientation::PRINT_AREA, BOOL bPos = FALSE );
     inline SwFmtHoriOrient &operator=( const SwFmtHoriOrient &rCpy );
 
-    // "pure virtual methods" of SfxPoolItem
+    // "Pure virtual methods" of SfxPoolItem.
     virtual int             operator==( const SfxPoolItem& ) const;
     virtual SfxPoolItem*	Clone( SfxItemPool* pPool = 0 ) const;
     virtual SfxItemPresentation GetPresentation( SfxItemPresentation ePres,
diff --git a/sw/inc/fmtpdsc.hxx b/sw/inc/fmtpdsc.hxx
index bc25e45..0682832 100644
--- a/sw/inc/fmtpdsc.hxx
+++ b/sw/inc/fmtpdsc.hxx
@@ -40,22 +40,22 @@ class SwHistory;
 class SwPaM;
 class IntlWrapper;
 
-//Pagedescriptor
-//Client vom SwPageDesc der durch das Attribut "beschrieben" wird.
+// Pagedescriptor
+// Client of SwPageDesc that is "described" by the attribute.
 
 #define	IVER_FMTPAGEDESC_NOAUTO	((USHORT)0x0001)
 #define IVER_FMTPAGEDESC_LONGPAGE	((USHORT)0x0002)
 
 class SW_DLLPUBLIC SwFmtPageDesc : public SfxPoolItem, public SwClient
 {
-    // diese "Doc"-Funktion ist friend, um nach dem kopieren das
-    // Auto-Flag setzen zu koennen !!
+    // This "Doc"-function is made friend in order to be able
+    // to set the auto-flag after copying!!
     friend BOOL InsAttr( SwDoc*, const SwPaM &, const SfxItemSet&, USHORT,
                         SwHistory* );
-    USHORT nNumOffset;			// Seitennummer Offset
-    USHORT nDescNameIdx;		// SW3-Reader: Stringpool-Index des Vorlagennamens
-    SwModify* pDefinedIn;		// Verweis auf das Objekt, in dem das
-                                // Attribut gesetzt wurde (CntntNode/Format)
+    USHORT nNumOffset;			// Offset page number.
+    USHORT nDescNameIdx;		// SW3-Reader: stringpool-index of style name.
+    SwModify* pDefinedIn;		// Points to the object in which the
+                                // attribute was set (CntntNode/Format).
 
 public:
     SwFmtPageDesc( const SwPageDesc *pDesc = 0 );
@@ -65,7 +65,7 @@ public:
 
     TYPEINFO();
 
-    // "pure virtual methods" of SfxPoolItem
+    // "Pure virtual methods" of SfxPoolItem.
     virtual int             operator==( const SfxPoolItem& ) const;
     virtual SfxPoolItem*	Clone( SfxItemPool* pPool = 0 ) const;
     virtual SfxItemPresentation GetPresentation( SfxItemPresentation ePres,
@@ -84,7 +84,7 @@ public:
     USHORT	GetNumOffset() const		{ return nNumOffset; }
     void	SetNumOffset( USHORT nNum ) { nNumOffset = nNum; }
 
-    // erfrage/setze, wo drin das Attribut verankert ist
+    // Query / set where attribute is anchored.
     inline const SwModify* GetDefinedIn() const { return pDefinedIn; }
     void ChgDefinedIn( const SwModify* pNew ) { pDefinedIn = (SwModify*)pNew; }
 };
diff --git a/sw/inc/fmtrfmrk.hxx b/sw/inc/fmtrfmrk.hxx
index b75af48..9738c80 100644
--- a/sw/inc/fmtrfmrk.hxx
+++ b/sw/inc/fmtrfmrk.hxx
@@ -34,14 +34,14 @@
 
 class SwTxtRefMark;
 
-// ATT_REFMARK *******************************************************
+// ATT_REFMARK
 
 class SwFmtRefMark : public SfxPoolItem
 {
     friend class SwTxtRefMark;
-    SwTxtRefMark* pTxtAttr;		// mein TextAttribut
+    SwTxtRefMark* pTxtAttr;
 
-    // protected CopyCtor
+    // Protected CopyCtor.
     SwFmtRefMark& operator=(const SwFmtRefMark& rRefMark);
     String aRefName;
 
@@ -50,7 +50,7 @@ public:
     SwFmtRefMark( const SwFmtRefMark& rRefMark );
     ~SwFmtRefMark( );
 
-    // "pure virtual methods" of SfxPoolItem
+    // "Pure virtual methods" of SfxPoolItem.
     virtual int             operator==( const SfxPoolItem& ) const;
     virtual SfxPoolItem*	Clone( SfxItemPool* pPool = 0 ) const;
 
diff --git a/sw/inc/fmtruby.hxx b/sw/inc/fmtruby.hxx
index 59771e0..5e88e3f 100644
--- a/sw/inc/fmtruby.hxx
+++ b/sw/inc/fmtruby.hxx
@@ -38,12 +38,12 @@ class SW_DLLPUBLIC SwFmtRuby : public SfxPoolItem
 {
     friend class SwTxtRuby;
 
-    String sRubyTxt;					// the ruby txt
-    String sCharFmtName;				// name of the charformat
-    SwTxtRuby* pTxtAttr;				// the TextAttribut
-    USHORT nCharFmtId;					// PoolId of the charformat
-    USHORT nPosition;					// Position of the Ruby-Character
-    USHORT nAdjustment;					// specific adjustment of the Ruby-Ch.
+    String sRubyTxt;					// The ruby txt.
+    String sCharFmtName;				// Name of the charformat.
+    SwTxtRuby* pTxtAttr;				// The TextAttribute.
+    USHORT nCharFmtId;					// PoolId of the charformat.
+    USHORT nPosition;					// Position of the Ruby-character.
+    USHORT nAdjustment;					// Specific adjustment of the Ruby-ch.
 
 public:
     SwFmtRuby( const String& rRubyTxt );
@@ -52,7 +52,7 @@ public:
 
     SwFmtRuby& operator=( const SwFmtRuby& rAttr );
 
-    // "pure virtual methods" of SfxPoolItem
+    // "Pure virtual methods" of SfxPoolItem.
     virtual int             operator==( const SfxPoolItem& ) const;
     virtual SfxPoolItem*	Clone( SfxItemPool* pPool = 0 ) const;
 
diff --git a/sw/inc/fmtsrnd.hxx b/sw/inc/fmtsrnd.hxx
index 0c6cad0..7483fe9 100644
--- a/sw/inc/fmtsrnd.hxx
+++ b/sw/inc/fmtsrnd.hxx
@@ -36,9 +36,7 @@
 #include <fmtsrndenum.hxx>
 class IntlWrapper;
 
-//SwFmtSurround, wie soll sich der ---------------
-//	Dokumentinhalt unter dem Rahmen verhalten ---
-
+// SwFmtSurround: How document content under the frame shall behave.
 class SW_DLLPUBLIC SwFmtSurround: public SfxEnumItem
 {
     BOOL	bAnchorOnly :1;
@@ -49,7 +47,7 @@ public:
     SwFmtSurround( const SwFmtSurround & );
     inline SwFmtSurround &operator=( const SwFmtSurround &rCpy );
 
-    // "pure virtual Methods" of SfxPoolItem
+    // "Pure virtual Methods" of SfxPoolItem.
     virtual int             operator==( const SfxPoolItem& ) const;
     virtual SfxPoolItem*	Clone( SfxItemPool* pPool = 0 ) const;
     virtual USHORT			GetValueCount() const;
diff --git a/sw/inc/fmturl.hxx b/sw/inc/fmturl.hxx
index 19fc623..1843043 100644
--- a/sw/inc/fmturl.hxx
+++ b/sw/inc/fmturl.hxx
@@ -40,12 +40,12 @@ class IntlWrapper;
 
 class SW_DLLPUBLIC SwFmtURL: public SfxPoolItem
 {
-    String	  sTargetFrameName;	// in diesen Frame soll die URL
-    String	  sURL;				// simple URL
-    String	  sName;			// Name of the anchor
-    ImageMap *pMap;				//ClientSide Images
+    String	  sTargetFrameName;	// Target frame for URL.
+    String	  sURL;				// Simple URL.
+    String	  sName;			// Name of the anchor.
+    ImageMap *pMap;				// ClientSide images.
 
-    BOOL      bIsServerMap;		//mit der URL eine ServerSideImageMap
+    BOOL      bIsServerMap;		// A ServerSideImageMap with the URL.
 
     SwFmtURL& operator=( const SwFmtURL& );
 
@@ -57,7 +57,7 @@ public:
 
     virtual ~SwFmtURL();
 
-    // "pure virtual methods" of SfxPoolItem
+    // "Pure virtual methods" of SfxPoolItem.
     virtual int             operator==( const SfxPoolItem& ) const;
     virtual SfxPoolItem*	Clone( SfxItemPool* pPool = 0 ) const;
     virtual SfxItemPresentation GetPresentation( SfxItemPresentation ePres,
@@ -70,7 +70,7 @@ public:
 
     void SetTargetFrameName( const String& rStr ) { sTargetFrameName = rStr; }
     void SetURL( const String &rURL, BOOL bServerMap );
-    void SetMap( const ImageMap *pM );	//Pointer will be copied
+    void SetMap( const ImageMap *pM );	// Pointer will be copied.
 
     const String   &GetTargetFrameName()const { return sTargetFrameName; }
     const String   &GetURL()			const { return sURL; }
diff --git a/sw/inc/format.hxx b/sw/inc/format.hxx
index 21f7bfb..0f9ba7e 100644
--- a/sw/inc/format.hxx
+++ b/sw/inc/format.hxx
@@ -30,9 +30,9 @@
 
 #include <tools/solar.h>
 #include "swdllapi.h"
-#include <errhdl.hxx>		// fuer ASSERT
-#include <swatrset.hxx>		// fuer SfxItemPool/-Set, Attr forward decl.
-#include <calbck.hxx>		// fuer SwModify
+#include <errhdl.hxx>		// For ASSERT.
+#include <swatrset.hxx>		// For SfxItemPool/-Set, Attr forward decl.
+#include <calbck.hxx>		// For SwModify.
 #include <hintids.hxx>
 
 class IDocumentSettingAccess;
@@ -50,18 +50,18 @@ class SW_DLLPUBLIC SwFmt : public SwModify
     SwAttrSet aSet;
 
     USHORT nWhichId;
-    USHORT nFmtId;			// Format-ID fuer Lesen/Schreiben
-    USHORT nPoolFmtId;		// Id-fuer "automatich" erzeugte Formate
-                            // (ist keine harte Attributierung !!)
-    USHORT nPoolHelpId;		// HelpId fuer diese Pool-Vorlage
-    BYTE nPoolHlpFileId; 	// FilePos ans Doc auf die Vorlagen-Hilfen
-    BOOL   bWritten : 1;	// TRUE: bereits geschrieben
-    BOOL   bAutoFmt : 1;	// FALSE: es handelt sich um eine Vorlage
-                            // ist dflt immer auf TRUE !
-    BOOL   bFmtInDTOR : 1;	// TRUE: das Format wird geloscht. Damit man in
-                            // der FmtChg-Message das erkennen kann!!!
-    BOOL   bAutoUpdateFmt : 1;	// TRUE: am Format werden die Attribute
-                            // eines kompletten Absatzes gesetzt (UI-seitig!)
+    USHORT nFmtId;            // Format-ID for reading / writing.
+    USHORT nPoolFmtId;        // Id for "automatically" created formats.
+                              // (is not hard attribution!!!)
+    USHORT nPoolHelpId;       // HelpId for this Pool-style.
+    BYTE nPoolHlpFileId;      // FilePos to Doc to these style helps.
+    BOOL   bWritten : 1;      // TRUE: already written.
+    BOOL   bAutoFmt : 1;      // FALSE: it is a template.
+                              // default is true!
+    BOOL   bFmtInDTOR : 1;    // TRUE: Format becomes deleted. In order to be able
+                              // to recognize this in FmtChg-message!!
+    BOOL   bAutoUpdateFmt : 1;// TRUE: Set attributes of a whole paragraph
+                              // at format (UI-side!).
 
 protected:
     SwFmt( SwAttrPool& rPool, const sal_Char* pFmtNm,
@@ -71,30 +71,30 @@ protected:
     SwFmt( const SwFmt& rFmt );
 
 public:
-    TYPEINFO();		//Bereits in Basisklasse Client drin.
+    TYPEINFO();		// Already in base class Client.
 
     virtual ~SwFmt();
     SwFmt &operator=(const SwFmt&);
 
-    // fuer die Abfrage der Writer-Funktionen
+    // for Querying of Writer-functions.
     USHORT Which() const { return nWhichId; }
 
     virtual void Modify( SfxPoolItem* pOldValue, SfxPoolItem* pNewValue );
-        // erfrage vom Format Informationen
+
+    // Query format information.
     virtual BOOL GetInfo( SfxPoolItem& ) const;
 
-    // kopiere Attribute; auch ueber Dokumentgrenzen hinweg
+    // Copy attributes even among documents.
     void CopyAttrs( const SwFmt&, BOOL bReplace=TRUE );
 
-    // loesche alle Attribute, die nicht in rFmt stehen
+    // Delete all attributes that are not in rFmt.
     void DelDiffs( const SfxItemSet& rSet );
     void DelDiffs( const SwFmt& rFmt ) { DelDiffs( rFmt.GetAttrSet() ); }
 
-    // Umhaengen des Formats (0 = Default)
+    // 0 is Default.
     BOOL SetDerivedFrom(SwFmt *pDerivedFrom = 0);
 
-    // Ist bInParents FALSE,
-    // wird nur in diesem Format nach dem Attribut gesucht.
+    // If bInParents is FALSE, search only in this format for attribute.
     inline const SfxPoolItem& GetFmtAttr( USHORT nWhich,
                                           BOOL bInParents = TRUE ) const;
     inline SfxItemState GetItemState( USHORT nWhich, BOOL bSrchInParent = TRUE,
@@ -103,9 +103,8 @@ public:
     virtual BOOL SetFmtAttr( const SfxItemSet& rSet );
     virtual BOOL ResetFmtAttr( USHORT nWhich1, USHORT nWhich2 = 0 );
 
-
-    // Nimmt alle Hints aus dem Delta-Array,
-    // liefert die Anzahl der geloeschten Hints
+    // Takes all hints from Delta-Array,
+    // returns count of deleted hints.
     virtual USHORT ResetAllFmtAttr();
 
     inline SwFmt* DerivedFrom() const { return (SwFmt*)pRegisteredIn; }
@@ -116,7 +115,7 @@ public:
     inline void SetName( const sal_Char* pNewName,
                          sal_Bool bBroadcast=sal_False);
 
-    // zur Abfrage des Attribute Arrays
+    // For querying the attribute array.
     inline const SwAttrSet& GetAttrSet() const { return aSet; }
 
     // Das Doc wird jetzt am SwAttrPool gesetzt. Dadurch hat man es immer
@@ -124,62 +123,59 @@ public:
     const SwDoc *GetDoc() const			{ return aSet.GetDoc(); }
           SwDoc *GetDoc() 				{ return aSet.GetDoc(); }
 
-    /** Provides access to the document settings interface
-     */
+    /// Provides access to the document settings interface.
     const IDocumentSettingAccess* getIDocumentSettingAccess() const;
 
-    /** Provides access to the document draw model interface
-     */
+    /// Provides access to the document draw model interface.
     const IDocumentDrawModelAccess* getIDocumentDrawModelAccess() const;
           IDocumentDrawModelAccess* getIDocumentDrawModelAccess();
 
-    /** Provides access to the document layout interface
-     */
+    /// Provides access to the document layout interface.
     const IDocumentLayoutAccess* getIDocumentLayoutAccess() const;
           IDocumentLayoutAccess* getIDocumentLayoutAccess();
 
-     /** Provides access to the document idle timer interface
-     */
-    IDocumentTimerAccess* getIDocumentTimerAccess();
+     /// Provides access to the document idle timer interface.
+     IDocumentTimerAccess* getIDocumentTimerAccess();
 
-     /** Provides access to the document idle timer interface
-     */
+     /// Provides access to the document idle timer interface.
     IDocumentFieldsAccess* getIDocumentFieldsAccess();
 
-     /** gives access to the chart data-provider
-     */
+     /// Gives access to the chart data-provider.
     IDocumentChartDataProviderAccess* getIDocumentChartDataProviderAccess();
 
-    // erfragen und setzen der Poolvorlagen-Id's
+    // Get and set Pool style IDs.
     USHORT GetPoolFmtId() const { return nPoolFmtId; }
     void SetPoolFmtId( USHORT nId ) { nPoolFmtId = nId; }
 
-    // erfragen und setzen der Hilfe-Id's fuer die Document-Vorlagen
+    // Get and set Help-IDs for document templates.
     USHORT GetPoolHelpId() const { return nPoolHelpId; }
     void SetPoolHelpId( USHORT nId ) { nPoolHelpId = nId; }
     BYTE GetPoolHlpFileId() const { return nPoolHlpFileId; }
     void SetPoolHlpFileId( BYTE nId ) { nPoolHlpFileId = nId; }
-    // erfrage die Attribut-Beschreibung, returnt den reingereichten String
+
+    // Get attribute-description. Returns passed string.
     void GetPresentation( SfxItemPresentation ePres,
         SfxMapUnit eCoreMetric,	SfxMapUnit ePresMetric,	String &rText ) const
         { aSet.GetPresentation( ePres, eCoreMetric,	ePresMetric, rText ); }
-    // Das Format-ID fuer Lesen/Schreiben:
+
+    // Format-ID for reading/writing:
     void   ResetWritten()    { bWritten = FALSE; }
 
-    // Abfragen/Setzen vom AutoFmt-Flag
+    // Query / set AutoFmt-flag.
     BOOL IsAuto() const 				{ return bAutoFmt; }
     void SetAuto( BOOL bNew = FALSE )	{ bAutoFmt = bNew; }
 
-    // Abfragen/Setzen vom bAutoUpdateFmt-Flag
+    // Query / set bAutoUpdateFmt-flag.
     BOOL IsAutoUpdateFmt() const 				{ return bAutoUpdateFmt; }
     void SetAutoUpdateFmt( BOOL bNew = TRUE )	{ bAutoUpdateFmt = bNew; }
 
     BOOL IsFmtInDTOR() const { return bFmtInDTOR; }
 
-    // GetMethoden: das Bool gibt an, ob nur im Set (FALSE) oder auch in
-    //				den Parents gesucht werden soll. Wird nichts gefunden,
-    //				wird das deflt. Attribut returnt.
-    // Charakter-Attribute	- impl. steht im charatr.hxx
+    // GetMethods: Bool indicates whether to search only in Set (FALSE)
+    // or also in Parents.
+    // If nothing is found the defaulted attribute is returned.
+
+    // Character-attributes	- implemented in charatr.hxx
     inline const SvxPostureItem      &GetPosture( BOOL = TRUE ) const;
     inline const SvxWeightItem       &GetWeight( BOOL = TRUE ) const;
     inline const SvxShadowedItem     &GetShadowed( BOOL = TRUE ) const;
@@ -220,7 +216,7 @@ public:
     inline const SvxCharReliefItem     &GetCharRelief( BOOL = TRUE ) const;
     inline const SvxCharHiddenItem   &GetCharHidden( BOOL = TRUE ) const;
 
     // Frame-Attribute	- impl. steht im frmatr.hxx,
     inline const SwFmtFillOrder           &GetFillOrder( BOOL = TRUE ) const;
     inline const SwFmtFrmSize             &GetFrmSize( BOOL = TRUE ) const;
     inline const SwFmtHeader          &GetHeader( BOOL = TRUE ) const;
@@ -261,7 +257,7 @@ public:
     // #i28701#
     inline const SwFmtWrapInfluenceOnObjPos& GetWrapInfluenceOnObjPos(BOOL = TRUE) const;
 
-    // Grafik-Attribute	- impl. steht im grfatr.hxx
+    // Graphics-attributes - implemented in grfatr.hxx
     inline const SwMirrorGrf          &GetMirrorGrf( BOOL = TRUE ) const;
     inline const SwCropGrf            &GetCropGrf( BOOL = TRUE ) const;
     inline const SwRotationGrf            &GetRotationGrf(BOOL = TRUE ) const;
@@ -275,7 +271,7 @@ public:
     inline const SwTransparencyGrf        &GetTransparencyGrf(BOOL = TRUE ) const;
     inline const SwDrawModeGrf            &GetDrawModeGrf(BOOL = TRUE ) const;
 
     // Paragraph-Attribute	- impl. steht im paratr.hxx
     inline const SvxLineSpacingItem       &GetLineSpacing( BOOL = TRUE ) const;
     inline const SvxAdjustItem            &GetAdjust( BOOL = TRUE ) const;
     inline const SvxFmtSplitItem      &GetSplit( BOOL = TRUE ) const;
@@ -293,7 +289,7 @@ public:
     inline const SvxParaGridItem        &GetParaGrid(BOOL = TRUE) const;
     inline const SwParaConnectBorderItem &GetParaConnectBorder(BOOL = TRUE ) const;
 
-    // TabellenBox-Attribute	- impl. steht im cellatr.hxx
+    // TableBox attributes - implemented in cellatr.hxx.
     inline  const SwTblBoxNumFormat     &GetTblBoxNumFmt( BOOL = TRUE ) const;
     inline  const SwTblBoxFormula       &GetTblBoxFormula( BOOL = TRUE ) const;
     inline  const SwTblBoxValue         &GetTblBoxValue( BOOL = TRUE ) const;
@@ -220,7 +216,7 @@ public:
     inline const SvxCharHiddenItem   &GetCharHidden( BOOL = TRUE ) const;
 
-    // Frame-Attribute	- impl. steht im frmatr.hxx,
+    // Frame-attributes	- implemented in frmatr.hxx.
     inline const SwFmtFillOrder           &GetFillOrder( BOOL = TRUE ) const;
     inline const SwFmtFrmSize             &GetFrmSize( BOOL = TRUE ) const;
@@ -275,7 +271,7 @@ public:
     inline const SwDrawModeGrf            &GetDrawModeGrf(BOOL = TRUE ) const;
 
-    // Paragraph-Attribute	- impl. steht im paratr.hxx
+    // Paragraph-attributes - implemented in paratr.hxx.
     inline const SvxLineSpacingItem       &GetLineSpacing( BOOL = TRUE ) const;
     inline const SvxAdjustItem            &GetAdjust( BOOL = TRUE ) const;


More information about the Libreoffice-commits mailing list